// Fetch data and draw pie chart
(async () => {
  const data = await d3.csv("https://gist.githubusercontent.com/numioguri/18d7ea134d1c1146cc55688173802b2f/raw/db9bbd8d3a3103723510127338a96dc8760c0118/.csv
");
  drawPieChart(data);
})();

function drawPieChart(data) {
  const width = 400;
  const height = 400;
  const radius = Math.min(width, height) / 2;

  const svg = d3.select("#pieChart")
    .append("svg")
    .attr("width", width)
    .attr("height", height)
    .append("g")
    .attr("transform", `translate(${width / 2}, ${height / 2})`);

  const color = d3.scaleOrdinal()
    .domain(data.map(d => d.Survived))
    .range(d3.schemeCategory10);

  const pie = d3.pie()
    .value(d => d.Survived);

  const data_ready = pie(d3.group(data, d => d.Survived));

  svg.selectAll('whatever')
    .data(data_ready)
    .enter()
    .append('path')
    .attr('d', d3.arc()
      .innerRadius(0)
      .outerRadius(radius)
    )
    .attr('fill', d => color(d.data.key))
    .attr("stroke", "black")
    .style("stroke-width", "2px")
    .style("opacity", 0.7);

  // Add legend
  const legend = svg.selectAll(".legend")
    .data(data_ready)
    .enter().append("g")
    .attr("class", "legend")
    .attr("transform", function (d, i) {
      return "translate(" + (width - 120) + "," + ((i * 20) - (height / 2)) + ")";
    });

  legend.append("rect")
    .attr("x", 0)
    .attr("width", 18)
    .attr("height", 18)
    .style("fill", d => color(d.data.key));

  legend.append("text")
    .attr("x", 24)
    .attr("y", 9)
    .attr("dy", ".35em")
    .text(d => d.data.key);
}
